%define major 0
%define libname %mklibname %name %major
%define libname_devel %mklibname -d %name

Name:           cmocka
Version:        1.1.5
Release:        %mkrel 1

License:        ASL 2.0
Group:          Development/C
Summary:        Lightweight library to simplify and generalize unit tests for C
Url:            http://cmocka.org

Source0:        https://cmocka.org/files/1.1/%{name}-%{version}.tar.xz

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  glibc-devel


%description
There are a variety of C unit testing frameworks available however many of them
are fairly complex and require the latest compiler technology. Some development
requires the use of old compilers which makes it difficult to use some unit
testing frameworks. In addition many unit testing frameworks assume the code
being tested is an application or module that is targeted to the same platform
that will ultimately execute the test. Because of this assumption many
frameworks require the inclusion of standard C library headers in the code
module being tested which may collide with the custom or incomplete
implementation of the C library utilized by the code under test.

Cmocka only requires a test application is linked with the standard C library
which minimizes conflicts with standard C library headers. Also, CMocka tries
to avoid the use of some of the newer features of C compilers.

This results in CMocka being a relatively small library that can be used to
test a variety of exotic code. If a developer wishes to simply test an
application with the latest compiler then other unit testing frameworks may be
preferable.

This is the successor of Google's Cmockery.

%package -n %{libname}
Group:          System/Libraries
Summary:        Lightweight library to simplify and generalize unit tests for C

%description -n %{libname}
There are a variety of C unit testing frameworks available however many of them
are fairly complex and require the latest compiler technology. Some development
requires the use of old compilers which makes it difficult to use some unit
testing frameworks. In addition many unit testing frameworks assume the code
being tested is an application or module that is targeted to the same platform
that will ultimately execute the test. Because of this assumption many
frameworks require the inclusion of standard C library headers in the code
module being tested which may collide with the custom or incomplete
implementation of the C library utilized by the code under test.

CMocka only requires a test application is linked with the standard C library
which minimizes conflicts with standard C library headers. Also, CMocka tries
to avoid the use of some of the newer features of C compilers.

This results in CMocka being a relatively small library that can be used to
test a variety of exotic code. If a developer wishes to simply test an
application with the latest compiler then other unit testing frameworks may be
preferable.

This is the successor of Google's Cmockery.

%package -n %{libname}-static-devel
Group:          Development/Libraries
Summary:        Lightweight library to simplify and generalize unit tests for C
Requires:       %{libname_devel} = %{version}-%{release}

%description -n %{libname}-static-devel
Static version of the cmocka library.

%package -n %{libname_devel}
Group:          Development/Libraries
Summary:        Development headers for the cmocka library
Provides:       libcmocka-devel = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}

%description -n %{libname_devel}
Development headers for the cmocka unit testing library.

%prep
%setup -q

%build
%cmake \
  -DWITH_STATIC_LIB=ON \
  -DWITH_CMOCKERY_SUPPORT=ON \
  -DUNIT_TESTING=ON \
  -DCMAKE_BUILD_TYPE=RelWithDebInfo

%make_build
make doc
make docs

%install
pushd ./build
%make_install
popd

%check
# The test suite doesn't automatically know to look at the "built"
# library, so we force it by creating an LD_LIBRARY_PATH
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
pushd ./build
make test || cat Testing/Temporary/LastTest.log
popd

%files -n %{libname}
%doc AUTHORS README.md ChangeLog COPYING
%{_libdir}/libcmocka.so.%{major}
%{_libdir}/libcmocka.so.%{major}.*

%files -n %{libname}-static-devel
%{_libdir}/libcmocka-static.a

%files -n %{libname_devel}
%doc build/doc/html
%{_includedir}/cmocka.h
%{_includedir}/cmocka_pbc.h
%{_includedir}/cmockery/cmockery.h
%{_includedir}/cmockery/pbc.h
%{_libdir}/libcmocka.so
%{_libdir}/pkgconfig/cmocka.pc
%{_libdir}/cmake/cmocka/cmocka-config-version.cmake
%{_libdir}/cmake/cmocka/cmocka-config.cmake


%changelog
* Fri Apr 05 2019 tex 1.1.5-1pclos2019
- New version 1.1.5
